@@ -1,5 +1,5 @@
-use criterion::{criterion_group, criterion_main, Criterion};
-use gix::{open, ThreadSafeRepository};
+use criterion::{Criterion, criterion_group, criterion_main};
+use gix::{ThreadSafeRepository, open};
 use onefetch::{cli::CliOptions, info::build_info};
 use std::hint::black_box;
 
