@@ -4,16 +4,16 @@ use crate::cli::MyRegex;
 use anyhow::Result;
 use gix::bstr::BString;
 use gix::bstr::ByteSlice;
-use gix::diff::tree_with_rewrites::Change;
 use gix::diff::Options;
+use gix::diff::tree_with_rewrites::Change;
 use gix::prelude::ObjectIdExt;
 use gix::revision::walk::Sorting;
 use gix::traverse::commit::simple::CommitTimeOrder;
 use gix::{Commit, ObjectId};
 use std::collections::HashMap;
-use std::sync::atomic::{AtomicBool, AtomicUsize, Ordering};
-use std::sync::mpsc::{channel, Sender};
 use std::sync::Arc;
+use std::sync::atomic::{AtomicBool, AtomicUsize, Ordering};
+use std::sync::mpsc::{Sender, channel};
 use std::thread::JoinHandle;
 
 pub mod metrics;
