@@ -17,16 +17,16 @@ use self::pending::PendingInfo;
 use self::project::ProjectInfo;
 use self::size::SizeInfo;
 use self::title::Title;
-use self::url::get_repo_url;
 use self::url::UrlInfo;
+use self::url::get_repo_url;
 use self::utils::info_field::{InfoField, InfoType};
 use self::version::VersionInfo;
-use crate::cli::{is_truecolor_terminal, CliOptions, NumberSeparator, When};
+use crate::cli::{CliOptions, NumberSeparator, When, is_truecolor_terminal};
 use crate::ui::get_ascii_colors;
 use crate::ui::text_colors::TextColors;
 use anyhow::{Context, Result};
-use gix::sec::trust::Mapping;
 use gix::Repository;
+use gix::sec::trust::Mapping;
 use onefetch_manifest::Manifest;
 use owo_colors::{DynColors, OwoColorize};
 use serde::Serialize;
@@ -79,17 +79,17 @@ struct InfoBuilder {
 
 impl std::fmt::Display for Info {
     fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
-        //Title
+        // Title
         if let Some(title) = &self.title {
             write!(f, "{title}")?;
         }
 
-        //Info lines
+        // Info lines
         for info_field in self.info_fields.iter() {
             info_field.write_styled(f, self.no_bold, &self.text_colors)?;
         }
 
-        //Palette
+        // Palette
         if !self.no_color_palette {
             writeln!(
                 f,
@@ -159,7 +159,9 @@ pub fn build_info(cli_options: &CliOptions) -> Result<Info> {
         .join()
         .ok()
         .context("BUG: panic in language statistics thread")?;
-    let dominant_language = langs::get_main_language(loc_by_language.as_ref());
+    let dominant_language = loc_by_language
+        .as_ref()
+        .map(|v| langs::get_main_language(v));
     let ascii_colors = get_ascii_colors(
         dominant_language.as_ref(),
         cli_options.ascii.ascii_language.as_ref(),
@@ -324,17 +326,17 @@ impl InfoBuilder {
         text_colors: &TextColors,
         cli_options: &CliOptions,
     ) -> Self {
-        if !self.disabled_fields.contains(&InfoType::Languages) {
-            if let Some(loc_by_language) = loc_by_language_opt {
-                let languages = LanguagesInfo::new(
-                    loc_by_language,
-                    true_color,
-                    number_of_languages,
-                    text_colors.info,
-                    cli_options.visuals.nerd_fonts,
-                );
-                self.info_fields.push(Box::new(languages));
-            }
+        if !self.disabled_fields.contains(&InfoType::Languages)
+            && let Some(loc_by_language) = loc_by_language_opt
+        {
+            let languages = LanguagesInfo::new(
+                loc_by_language,
+                true_color,
+                number_of_languages,
+                text_colors.info,
+                cli_options.visuals.nerd_fonts,
+            );
+            self.info_fields.push(Box::new(languages));
         }
         self
     }
@@ -434,11 +436,11 @@ impl InfoBuilder {
         loc_by_language_opt: Option<&Vec<(Language, usize)>>,
         number_separator: NumberSeparator,
     ) -> Self {
-        if !self.disabled_fields.contains(&InfoType::LinesOfCode) {
-            if let Some(loc_by_language) = loc_by_language_opt {
-                let lines_of_code = LocInfo::new(loc_by_language, number_separator);
-                self.info_fields.push(Box::new(lines_of_code));
-            }
+        if !self.disabled_fields.contains(&InfoType::LinesOfCode)
+            && let Some(loc_by_language) = loc_by_language_opt
+        {
+            let lines_of_code = LocInfo::new(loc_by_language, number_separator);
+            self.info_fields.push(Box::new(lines_of_code));
         }
         self
     }
